/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGithubReleaseConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release#id DataGithubRelease#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release#owner DataGithubRelease#owner}
    */
    readonly owner: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release#release_id DataGithubRelease#release_id}
    */
    readonly releaseId?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release#release_tag DataGithubRelease#release_tag}
    */
    readonly releaseTag?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release#repository DataGithubRelease#repository}
    */
    readonly repository: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release#retrieve_by DataGithubRelease#retrieve_by}
    */
    readonly retrieveBy: string;
}
export interface DataGithubReleaseAssets {
}
export declare function dataGithubReleaseAssetsToTerraform(struct?: DataGithubReleaseAssets): any;
export declare function dataGithubReleaseAssetsToHclTerraform(struct?: DataGithubReleaseAssets): any;
export declare class DataGithubReleaseAssetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGithubReleaseAssets | undefined;
    set internalValue(value: DataGithubReleaseAssets | undefined);
    get browserDownloadUrl(): string;
    get contentType(): string;
    get createdAt(): string;
    get id(): number;
    get label(): string;
    get name(): string;
    get nodeId(): string;
    get size(): number;
    get updatedAt(): string;
    get url(): string;
}
export declare class DataGithubReleaseAssetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGithubReleaseAssetsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release github_release}
*/
export declare class DataGithubRelease extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "github_release";
    /**
    * Generates CDKTF code for importing a DataGithubRelease resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataGithubRelease to import
    * @param importFromId The id of the existing DataGithubRelease that should be imported. Refer to the {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataGithubRelease to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/integrations/github/6.3.0/docs/data-sources/release github_release} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGithubReleaseConfig
    */
    constructor(scope: Construct, id: string, config: DataGithubReleaseConfig);
    get assertsUrl(): string;
    private _assets;
    get assets(): DataGithubReleaseAssetsList;
    get assetsUrl(): string;
    get body(): string;
    get createdAt(): string;
    get draft(): cdktf.IResolvable;
    get htmlUrl(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _owner?;
    get owner(): string;
    set owner(value: string);
    get ownerInput(): string | undefined;
    get prerelease(): cdktf.IResolvable;
    get publishedAt(): string;
    private _releaseId?;
    get releaseId(): number;
    set releaseId(value: number);
    resetReleaseId(): void;
    get releaseIdInput(): number | undefined;
    private _releaseTag?;
    get releaseTag(): string;
    set releaseTag(value: string);
    resetReleaseTag(): void;
    get releaseTagInput(): string | undefined;
    private _repository?;
    get repository(): string;
    set repository(value: string);
    get repositoryInput(): string | undefined;
    private _retrieveBy?;
    get retrieveBy(): string;
    set retrieveBy(value: string);
    get retrieveByInput(): string | undefined;
    get tarballUrl(): string;
    get targetCommitish(): string;
    get uploadUrl(): string;
    get url(): string;
    get zipballUrl(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
